font_google: Google Font specification

View source: R/font_set.R

font_googleR Documentation

Google Font specification

Description

Create a font specification for a Google Font, to be used with font_set().

Usage

font_google(family, subset = c("latin", "latin-ext"))

Arguments

family

family name of a 'Google Fonts', for example, "Open Sans", "Roboto", "Fira Code" or "Fira Sans Condensed".

subset

font subset, a character vector, it defaults to only "latin" and "latin-ext".

Value

An object of class font_spec.

See Also

Other font set functions: font_liberation(), font_set(), font_set_auto(), font_set_liberation()

Examples

font_google("Roboto")

gdtools documentation built on May 26, 2026, 1:06 a.m.