font_set_auto: Automatic font set

View source: R/font_set.R

font_set_autoR Documentation

Automatic font set

Description

Build a font_set() by detecting the best available system fonts for each role (sans, serif, mono, symbol).

For each role a list of well-known fonts is tried in order. When none is found on the system, the corresponding Liberation font is used as a guaranteed offline fallback.

Role Candidates (in order) Fallback
sans Arial, Helvetica, DejaVu Sans Liberation Sans
serif Times New Roman, Times, DejaVu Serif Liberation Serif
mono Courier New, Courier, DejaVu Sans Mono Liberation Mono
symbol Symbol, Apple Symbols Liberation Sans

Usage

font_set_auto()

Value

An object of class font_set.

See Also

font_set(), font_set_liberation()

Other font set functions: font_google(), font_liberation(), font_set(), font_set_liberation()

Examples

fonts <- font_set_auto()
fonts

gdtools documentation built on May 26, 2026, 1:06 a.m.