Learn R Programming

gdtools (version 0.5.0)

register_liberationsans: Register font 'Liberation Sans'

Description

Register font 'Liberation Sans' so that it can be used with devices using the 'systemfonts' package, i.e. the 'flextable' package and graphic outputs generated with the 'ragg', 'svglite' and 'ggiraph' packages.

Usage

register_liberationsans(name = "Liberation Sans")

Value

TRUE if the operation went ok.

Arguments

name

the name to use for the font family when registering with 'systemfonts'. Using a custom name (e.g. "sans", "serif", "mono") allows devices like 'ragg' to resolve generic family names to this font.

See Also

font_set_liberation(), font_set()

Other functions for font management: addGFontHtmlDependency(), fonts_cache_dir(), gfontHtmlDependency(), install_gfont_script(), installed_gfonts(), liberationmonoHtmlDependency(), liberationsansHtmlDependency(), liberationserifHtmlDependency(), register_gfont(), register_liberationmono(), register_liberationserif()

Examples

Run this code
register_liberationsans()
register_liberationsans(name = "sans")

Run the code above in your browser using DataLab