Check if a font family exists in available fonts.
Arguments
- font_family
font family name (case sensitive)
- system_only
If
TRUE, only look in system-installed fonts (as returned bysystemfonts::system_fonts()). This is useful to verify that a font will be found by fontconfig, which is the font resolution mechanism used by Cairo devices at rendering time. WhenFALSE(the default), both system and registered fonts are considered.